OC.L10N.register(
    "news",
    {
    "Unread articles" : "Bài chưa đọc",
    "Download" : "Tải về",
    "Close" : "Đóng",
    "Web address" : "Địa chỉ Web",
    "No folder" : "Không có thư mục nào",
    "Folder name" : "Tên thư mục",
    "Username" : "Tên đăng nhập",
    "Password" : "Mật khẩu",
    "Feed exists already!" : "Nguồn đã tồn tại",
    "New folder" : "Tạo thư mục",
    "Folder exists already!" : "Thư mục đã tồn tại!",
    "Credentials" : "Giấy chứng nhận",
    "Subscribe" : "Theo dõi",
    "Last job ran {relativeTime}." : "Công việc cuối cùng đã chạy {relativeTime}.",
    "Move" : "Dịch chuyển",
    "Share" : "Chia sẻ",
    "Off" : "Tắt",
    "Mark read" : "Đánh dấu là đã đọc",
    "All articles" : "Mọi bài viết",
    "Starred" : "Starred",
    "Settings" : "Cài đặt",
    "Documentation" : "Tài liệu hướng dẫn",
    "Keyboard shortcuts" : "Phím tắt",
    "Rename" : "Sửa tên",
    "Delete" : "Xóa",
    "Rename Feed" : "Đổi tên nguồn dữ liệu",
    "Newest first" : "Mới trước",
    "Oldest first" : "Cũ trước",
    "Mark unread" : "Đánh dấu là chưa đọc",
    "by" : "bởi",
    "Open website" : "Mở trang web",
    "Title" : "Tên",
    "Folder" : "Thư mục",
    "Not available" : "Không khả dụng",
    "Keyboard shortcut" : "Phím tắt",
    "Action" : "Hành động",
    "right" : "phải",
    "left" : "trái",
    "Refresh" : "Làm mới",
    "Shift" : "Shift"
},
"nplurals=1; plural=0;");
